@@ -10,8 +10,10 @@ decorator.
 __author__ = "Jakob Simon-Gaarde"
 
 from ladon.ladonizer.collection import global_service_collection
-from ladon.types import validate_type
+from ladon.types import validate_type,result_to_dict
 from ladon.exceptions.ladonizer import *
+import ladon.tools.log as log
+import time
 
 def ladonize(*def_args,**def_kw):
 	"""
@@ -74,8 +76,28 @@ def ladonize(*def_args,**def_kw):
 			# Call the userspace service method (**kw will be used to transport Ladon info
 			# and tools all the way to userspace of the service method. I.e. the TypeConverter
 			# is passed with the keyword "LADON_METHOD_TC")
-			res = f(*args,**kw)
+			debug_mode = log.get_loglevel()>=6
+			if debug_mode:
+				log_line = [
+					'Method:%s.%s' % (lmi.sinfo.servicename,lmi._func_name),
+					'RequestPositionalArgs:%s' % str(args[1:]),
+					'RequestKeywordArgs:%s' % str(kw)]
 			
+			if debug_mode:
+				try:
+					start = time.time()
+					res = f(*args,**kw)
+					log_line.insert(0,'ExecutionTime:%s' % str(time.time()-start))
+				except Exception as e:
+					log_line += ['Exception:%s' % str(e) ]
+					log.debug('\t%s' % ('\t'.join(log_line)))
+					raise e
+				
+				log_line += [ 'ReturnValue:%s' % str(result_to_dict(lmi,res)) ]
+				log.debug('\t%s' % ('\t'.join(log_line)))
+				
+			else:
+				res = f(*args,**kw)
 			# Check the return type
 			if not validate_type(lmi._rtype,res):
 				# Raise Arg-type mismatch 
