@@ -34,12 +34,15 @@ def set_loglevel(level):
 	global cur_loglevel
 	cur_loglevel = level
 
+def get_loglevel():
+	global cur_loglevel
+	return cur_loglevel
+
 cur_logfile = '/tmp/ladon.log'
 def set_logfile(logfile):
 	global cur_logfile
 	cur_logfile = logfile
 
-
 def write(msg,loglevel=3,context=None,force=False):
 	
 	"""
